*=====================================================================================*
*                                  analysis.do                                        *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  Lechner & Leopold 2014, replication files                                          *
*  last update: 25-08-14                                                              *
*  data: soeplong 1984-2012, version 29, release 2013                                 *
*-------------------------------------------------------------------------------------*


*-------------------------------------------------------------------------------------*
* 1. Select variables                                                                 *
*-------------------------------------------------------------------------------------*

* Load pl (main person file; long format)
use "${SOEP}/pl.dta", clear


* Set label language to English
label language EN


* Sort and keep only relevant variables
sort pid (syear)
keep syear pid pli0098 plb0021 plh0182 ple0008 pci0041
order pid syear 


* Merge 

// Merge data from ppfad (basic variables; wide format) 
merge 1:1 pid syear using "${dataDir}/pgen.dta", ///
	keepusing (pgcasmin pgfamstd pgemplst) keep (1 3) nogen

// Merge data from pgen (generated variables; long format)
merge m:1 pid using "${dataDir}/ppfad.dta", ///
	keepusing (letztbef gebjahr sex todjahr germborn loc1989 migback) keep (1 3) nogen

	
* Correct label of religiosity variable (pli0098)

// The label is incorrect in soeplong v29 (release 2013)
// This patch was provided to the authors by the SOEP group
label define relig 					///
	1 "[1] Every Week" 				///
	2 "[2] Every Month" 			///
	3 "[3] Less Frequently" 		///
	4 "[4] never" 					///
	11 "[11] Daily" 				///
	12 "[12] At Least Once A Week"  ///
	13 "[13] At Least Once A Month" /// 
	14 "[14] Less Frequently" 		///
	15 "[15] never"					///
	, replace
label values pli0098 relig

// Check if the patch returns plausible results
tab pli0098 pci0041 	// OK
drop pci0041			// this variable is no longer necessary


* Define unemployment

// Our definition of unemployment relies of respondents' reports 
// of being in registered unemployment at the time of the interview.

gen unemployed = plb0021 == 1
	label variable unemployed "Registered as unemployed"

	
*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*
	
	
*-------------------------------------------------------------------------------------*
* 2. Select sample                                                                    *
*-------------------------------------------------------------------------------------*

* Sample size before selections

distinct pid


*-------------------------------------------------------------------------------------*
* 2.1 Delete observations before 1990       								          *
*-------------------------------------------------------------------------------------*

// Information about church attendance is available since 1990

drop if syear < 1990


*-------------------------------------------------------------------------------------*
* 2.2 Delete respondents who were never umemployed   						          *
*-------------------------------------------------------------------------------------*

bysort pid (syear): egen aux = max(unemployed) 	
// aux is 1 if a respondent has reported registered unemployment at least once
drop if aux == 0 
drop aux
 
 
*-------------------------------------------------------------------------------------*
* 2.3 Select transitions to unemployment and observations of continued unemployment   *
*-------------------------------------------------------------------------------------*

/*
This step comprises six substeps:
	2.3.1 Identify first unemployment spell observed in the data (after 1990) 
		  and generate indicator variable for transition to initial unemployment
	2.3.2 Keep only observations of respondents who remain unemployed in the panel 
		  (i.e., registered as unemployed at the interview)
	2.3.3 Delete previous observations in employment; 
		  keep only the employment spell preceding the initial transition to unemployment	
	2.3.4 Delete respondents who are not employed upon first observation 
		  after the previous restrictions
	2.3.5 Remove gaps between panel waves; keep only consecutive observations
	2.3.6 Delete respondents for whom we did not observe the transition to unemployment 
		  after applying the previous restrictions
*/

* 2.3.1

bysort pid (syear): gen nr = _n 
// nr counts number of panel observations for each respondent
gen aux = nr if unemployed == 1 
// aux: number of observation when observed in registered umemployment
bysort pid (syear): egen aux1 = min(aux) 				
// aux1: minimum value of aux (i.e. earliest observation in unemployment)
gen tr_unemp = 0									
replace tr_unemp = 1 if aux == aux1 & aux!=. 			
// tr_unemp is 1 in the year in which a person is intially observed in registered unemployment
label variable tr_unemp "Initial transition to unemployment"
		
* 2.3.2 

gen re_emp = 0
replace re_emp = 1 if nr > aux1 & unemployed  != 1 		
// re-employed = no longer registered as unemployed
drop aux aux1
gen aux = nr if re_emp == 1 								
// identify first spell of re-employment
bysort pid (syear): egen aux1 = min(aux) 				
// aux1 denotes the number of the first spell of re-employment (written into every row of a respondent)
drop if aux!= . & aux >= aux1 							
// drop if number of observation >= number of first observation at first reemployment
drop aux aux1 re_emp nr

* 2.3.3

bysort pid (syear): gen nr = _n 						
// nr: enumerator for remaining observations per respondent
gen aux = nr if unemployed  == 1 
bysort pid (syear): egen aux1 = min(aux)
drop if aux1 - nr > 1   								
// aux1 is > 1 in the years to be deleted
drop aux aux1 nr

* 2.3.4

bysort pid (syear): gen nr = _n 						
// update enumerator of observations
gen aux = nr == 1 & pgemplst == 5 						
// aux is 1 if criterion for exclusion is fulfilled
bysort pid (syear): egen aux1 = max(aux)
drop if aux1 == 1
drop aux aux1 nr

* 2.3.5

/* 
This step ensures that respondents are observed across subsequent panel waves, without gaps
Procedure: Define an indicator aux that equals 1 if there is no gap between the current and 
the previous observation; delete observations > _n[1] (initial observation) that do not meet 
this condition; repeat until no gaps remain; the command has to be repeated until all 
deletions are complete; this is accomplished by the loop
*/

foreach num of numlist 1/20 {
	bysort pid (syear): gen nr`num' = _n
	bysort pid (syear): gen aux`num' = syear[_n] == syear[_n-1] + 1 
	// aux is 1 if the previous observation is exactly one year before the current one
	drop if nr`num' > 1 & aux`num' == 0
	drop aux`num' nr`num'
	}
	*

* 2.3.6

bysort pid (syear): egen aux = max(unemployed) 			
// aux is 1 if a transition to unemployment was observed
drop if aux == 0
bysort pid (syear): gen nr = _n
gen aux1 = nr == 1 & unemployed == 1 					
// aux1 is 1 if a transition was observed in the first spell
bysort pid (syear): egen aux2 = max(aux1)
drop if aux2 == 1
drop aux aux1 aux2 nr


*-------------------------------------------------------------------------------------*
* 2.4 Delete observations with insufficient case numbers for analysis			      *
*-------------------------------------------------------------------------------------*

// We analyse up to 3 observations of unemployment; 
// after that, case numbers are insufficient to investigate buffer effects

bysort pid (syear): gen nr = _n 						
// update enumerator
drop if nr > 4
gen time = nr
replace time = time - 1
	label variable time "Time"
	label define time 0 "0" 1 "0-1" 2 "1-2" 3 "2-3", replace
	label values time time
drop nr


*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*


*-------------------------------------------------------------------------------------*
* 3. Definition of analytical variables							     			      *
*-------------------------------------------------------------------------------------*


*-------------------------------------------------------------------------------------*
* 3.1 Outcome: Global life satisfaction		     				     			      *
*-------------------------------------------------------------------------------------*

gen ls = plh0182 
mvdecode ls, mv(-5 -1)
	label variable ls "Global life satisfaction (0-10)"

	
*-------------------------------------------------------------------------------------*
* 3.2 Predictor: Religiosity         		     				     			      *
*-------------------------------------------------------------------------------------*

clonevar rel = pli0098
mvdecode rel, mv(-8 -2 -1)
	label variable rel "Church attendance"
drop pli0098


* Define religiosity as a time-constant variable

/*
We use the measurement before the transition (t0), if available; 
if not, we use the measurement at the transition (t1). Because religiosity 
is measured at least bianually, this yields valid data for all respondents.
*/

gen rel_tc = .
bysort pid (syear): replace rel_tc = rel[1] if rel[1] != . 						
// take value at 1st observation, if valid 
fre rel_tc if time == 0															
// descriptive information: what share of the data is measured at t0?
bysort pid (syear): replace rel_tc = rel[2] if rel_tc == . & rel[2] != . 		
// if value at 1st not valid, take value at 2nd, if valid 
label variable rel_tc "Religiosity (time-constant)"
label values rel_tc relig


* Define buffer variables

gen b1 = rel_tc==1|rel_tc==11|rel_tc==12 			
// b1: church at least weekly
gen b2 = rel_tc==2|rel_tc==13 						
// b2: church at least monthly, not weekly
gen b3 = rel_tc==3|rel_tc==14 						
// b3: church more than never but less than monthly
label variable b1 "Weekly church attendance"
label variable b2 "Monthly church attendance"
label variable b3 "Less than monthly church attendance"


*-------------------------------------------------------------------------------------*
* 3.3 Controls				         		     				     			      *
*-------------------------------------------------------------------------------------*

* Age and age at transition

gen age = syear - gebjahr
	label variable age "Age"
gen age_tr = age if tr_unemp == 1
sum age_tr,d
gen aux = age_tr - r(mean)
bysort pid (syear): egen age_tr_c = max(aux)
drop aux
label variable age_tr "Age at transition to unemployment"
label variable age_tr_c "Age at transition to unemployment (mean-centered)"


* Marital Status

recode pgfamstd 			///
	(1 2 6 = 1 "Married")	/// 
	(3 = 2 "Single") 		///
	(4 = 3 "Divorced") 		///
	(5 = 4 "Widowed")		///
	, gen(marstat)
label variable marstat "Marital status"
drop pgfamstd


* Period effects

recode syear 					///
	(1990/1994 = 1 "1990-94") 	///
	(1995/1999 = 2 "1995-99") 	///
	(2000/2004 = 3 "2000-04") 	///
	(2005/2008 = 4 "2005-08") 	///
	(2009/2012 = 5 "2009-12")	///
	, gen (period)
label variable period "Period"


* East Germany

gen east = loc1989 == 1
label variable east "East Germany"


* Migration background

gen mig = migback != 1
	label variable mig "Migration background"


*-------------------------------------------------------------------------------------*
* 3.4 Indicator variables for dropout (used for robustness checks)		         	  *
*-------------------------------------------------------------------------------------*

/*
There are three reasons why respondents may drop out:
	(1) No longer unemployed (but still observed in the SOEP)
	(2) Unit-nonresponse / panel attrition
	(3) Death
*/

bysort pid (syear): egen aux = max(syear) 								
// aux indicates the year of last observation in our data
gen aux1 = syear == aux 												
// aux1 equals 1 only in the last year of observation
gen dropout = .
replace dropout = 1 if (aux < letztbef) & aux1 == 1 							
// stayed = at least one subsequent observation in the SOEP after last observation in our sample
replace dropout = 2 if (aux == 2012) & aux1 == 1 								
// censored = last observation in our sample was at the latest wave of the SOEP
replace dropout = 3 if (aux == letztbef) & (letztbef != 2012 & aux1 == 1) 		
// left = respondent left the panel (i.e., year of last observation in unemployment = year of last observation in the SOEP)
replace dropout = 4 if (aux == (todjahr-1)) & (letztbef != 2012 & aux1 == 1) 	
// died = respondent died (i.e., year of last observation in unemployment precedes year of death)
drop aux aux1
label variable dropout "Dropout"
label define drop 					///
	1 "Stayed in SOEP (no dropout)" ///
	2 "Right-censored in 2012" 		///
	3 "Left the SOEP" 				///
	4 "Died after last observation"
label values dropout drop
	
	
*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*


** PREPARATION COMPLETE **


*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

* Save data for analysis

order pid syear time
save "${posted}/data", replace



*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*


*-------------------------------------------------------------------------------------*
* 4. Analysis																		  *
*-------------------------------------------------------------------------------------*

use "${posted}/data", clear


*-------------------------------------------------------------------------------------*
* 4.1 Descriptive information    													  *
*-------------------------------------------------------------------------------------*

* Employment status before the transition to unemployment

tab pgemplst if time == 0

* Survey years in which transitions to unemployment occurred

tab syear if time == 1

* Reasons for dropout

fre dropout

* Frequency of church attendance

fre b1 b2 b3 if time == 0


*-------------------------------------------------------------------------------------*
* 4.1 Fixed-effects model	    													  *
*-------------------------------------------------------------------------------------*

/*
- The model estimates linear change in life satisfaction (11-point scale) 
  with person-level fixed-effects.
- The reference period (time = 0) is the last observation in employment before 
  the transition to unemployment. The subsequent time periods (time = 1, 2, 3) 
  are up to 3 consecutive observations in unemployment. 
- Because we treat religiosity as time-constant, we interact the buffer variables 
  (b1, b2, b3) with the time variable.
- The constant is the grand mean of life satisfaction in the reference period, 
  conditional on all covariates equaling zero.
- We control for age at the transition to unemployment 
  (time-constant; interacted with the time variable), changes in marital status, 
  and period effects.
- The model includes the following independent variables:
 	   time x b1 	 		time interacted with buffer 1 "weekly church attendance"
	   time x b2 	 		time interacted with buffer 2 "monthly church attendance"
	   time x b3 	 		time interacted with buffer 3 "less than monthly church attendance"
	   time x age_tr 		time interacted with age at the transition to unemployment
	   time x east 			time interacted with East Germany
	   time x mig			time interacted with migration background
	   marstat				marital status (married is reference)
	   period				period (2000-04 is reference)   
*/


* Set to panel data

xtset pid time


* Estimate the model

xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe

	
* Save Table 1 to Word

esttab using "${tables}/table_1.rtf", replace label 	///
	se wide starlevels(+ 0.10 * 0.05 ** 0.01) mtitles


* Figure 1  

xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe	
margins time, at			///
	   (b1=(1) 				/// Church attendance: Weekly
		b2=(0) 				/// 
		b3=(0)				/// 
		marstat=(1) 		///
		period=(3)) 		///
	vsquish noestimcheck post
est store A

xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe	
margins time, at			///
	   (b1=(0) 				///
		b2=(1) 				/// Church attendance: Monthly
		b3=(0)				/// 
		marstat=(1) 		///
		period=(3)) 		///
	vsquish noestimcheck post
est store B

xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe	
margins time, at			///
	   (b1=(0) 				///
		b2=(0) 				///
		b3=(1)				/// Church attendance: Less often
		marstat=(1) 		///
		period=(3)) 		///
	vsquish noestimcheck post
est store C

xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe	
margins time, at			///
	   (b1=(0) 				///
		b2=(0) 				///
		b3=(0)				/// Church attendance: Never
		marstat=(1) 		///
		period=(3)) 		///
	vsquish noestimcheck post
est store D


coefplot ///
		(A, label(Weekly) 	offset(0) msymbol(O) mcolor(black) msize(medlarge) lcolor(black)  lwidth(medthick) lpattern(solid) 		lcolor(black) noci)     ///
		(B, label(Monthly)	offset(0) msymbol(D) mcolor(black)   		       lcolor(black)  lwidth(medthick) lpattern(dash)	    lcolor(black) noci)     ///
		(C, label(Rarely)	offset(0) msymbol(S) mcolor(black)   		       lcolor(black)  lwidth(medthick) lpattern(shortdash)  lcolor(black) noci)     ///
		(D, label(Never)	offset(0) msymbol(T) mcolor(black)   		       lcolor(black)  lwidth(medthick) lpattern(dot) 		lcolor(black) noci)     ///
	, title 	("", size(small)) 																									   						///
				vertical recast(connected) ytitle("Life satisfaction", size(small)) ylab (6.7 (0.1) 5.8, labsize(small) angle(0)) 	   						///
				xtitle("Number of years unemployed", size(small)) xscale(titlegap(2)) xlab (, labsize(small)) 						  						///
				legend(region(lstyle(none)) ring(0) bplacement(swest) size(small) rows(4) title("Church attendance", size(small))) 	   						///
				graphregion(color(white) fcolor(white) icolor(white)) 																   						///
	saving("${graphs}/figure_1.emf", replace)
	
	
*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

*-------------------------------------------------------------------------------------*
* 4.2 Robustness checks  	    													  *
*-------------------------------------------------------------------------------------*

* (1) Keep only those who returned to employment

preserve
gen aux = dropout == 1
bysort pid (syear): egen keep = max(aux)
keep if keep == 1
xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe
restore


* (2) Keep only those who were observed at all four points in time

preserve
bysort pid (syear): egen aux = max(time)
keep if aux == 3
xtreg 	ls 					///
		time##b1 			///
		time##b2 			///
		time##b3 			///
		time##c.age_tr_c 	///
		time##east 			///
		time##mig 			///
		ib1.marstat 		///
		ib3.period			///
	, fe
restore


* (3) Further checks

// Test whether religious attendance is related to reasons for dropout

bysort pid (syear): egen drop = max(dropout)
mlogit drop b1 b2 b3 if time==0


*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

	
	
	
	
	
	